-- This code is property of the Ulysses development team, ALL RIGHTS RESERVED

gUsers = {} -- Keeps track of long term admins that will stay across map changes
gSayCmds = {} -- Keeps track of said commands ( IE: a player says "freezeall" )
gCmdHelp = {} -- Keeps track of our help table
gCvarHelp = {} -- Keeps track of our help table

-- eventPlayerSay - Called when someone says something, this will handle our say commands
function eventPlayerSay (userid, strText, bTeam)	
	local args = strText
	local argv = {}
	local argc
	args = string.sub( strText,string.len( _PlayerInfo( userid, "name" ) ) +3 )
	argv, argc = splitArgs( args )
	
	if argv[ 1 ] == nil or argv[ 1 ] == "" or gSayCmds[ argv[ 1 ] ] == nil then
		return strText
	end
	
	local cmd_access = gSayCmds[ argv[ 1 ] ].access
	local fn_call = gSayCmds[ argv[ 1 ] ].fn
	local min_args = gSayCmds[ argv[ 1 ] ].minArgs
	
	if cmd_access ~= nil then
		if hasAccess( userid, cmd_access ) == false then
			_PrintMessage( userid, HUD_PRINTCONSOLE, "You lack sufficient access to use this command!\n" )
			return strText
		end
	end
	
	if min_args ~= nil then
		if argc < min_args then
			_PrintMessage( userid, HUD_PRINTCONSOLE, "Insufficient parameters!\n" )
			return strText
		end
	end
	
	args = string.sub( args, string.len( argv[ 1 ] ) + 1 ) -- This gets rid of the actual command from the text
	table.remove( argv, 1 )	
	fn_call( userid, args, argv, argc )
	
	return strText
end

-- getUser - This function will give you a userid from a partial match of name or steamid ( if it's given a valid userid it will return it ).
function getUser( userid, user )
	if user == nil or userid == nil or type( userid ) ~= "number" or userid > 32 or userid <= 0 then
		error_msg( "getUser() was passed invalid paramaters!" )
		return
	end
	
	local result = nil
	local temp
	
	temp = tonumber( user )
	if temp ~= nil and temp > 0 and temp <= 32 and _PlayerInfo( temp, "connected" ) then -- Guess they mean the person's userid
		return temp -- And we're done!
	end
	
	local user = string.lower( user ) -- We want to make this a case insensitive search
			
	for i = 1, _MaxPlayers() do
		if _PlayerInfo( i, "connected" ) == true then
			temp = string.find( string.lower( _PlayerInfo( i, "name" ) ), user )
			if temp ~= nil then
				if result ~= nil then
					_PrintMessage( userid, HUD_PRINTCONSOLE, "There is more than one person with that partial name!\n" )
					return
				end
				result = i 
			end
		end
	end
	
	if result ~= nil then -- If and only if we have one result from partial names, return it!
		return result
	end
	
	 --No results in partial names? Let's get desperate and test steam ID's!
	for i = 1, _MaxPlayers() do
		if _PlayerInfo( i, "connected" ) == true then
			temp = string.find( string.lower( _PlayerInfo( i, "networkid" ) ), user )
			if temp ~= nil then
				if result ~= nil then
					_PrintMessage( userid, HUD_PRINTCONSOLE, "There is more than one person with that partial name!\n" )
					return
				end
				result = i 
			end
		end
	end
	
	if result ~= nil then -- If and only if we have one result from steam IDs, return it!
		return result
	end	
	
	_PrintMessage( userid, HUD_PRINTCONSOLE, "Sorry, I couldn't find the user you wanted to perform that action on!\n" )
	return nil
end

-- getAccess - returns the user's full access
function getAccess( userid )
	local steamid = _PlayerInfo( userid, "networkid" )
	if gUsers[ steamid ] ~= nil then
		return gUsers[ steamid ]
	elseif steamid == "UNKNOWN" and userid == 1  then
		return LISTEN_ADMIN_ACCESS
	else
		return nil
	end
end

-- hasAccess - If the user has the specified access, return true, otherwise false.
function hasAccess( userid, access )
	if access == nil then -- nil access means it's open for everyone!
		return true
	end
	
	local steamid = _PlayerInfo( userid, "networkid" )
	if gUsers[ steamid ] and string.find( gUsers[ steamid ], access ) ~= nil then
		return true
	elseif steamid == "UNKNOWN" and userid == 1 and string.find( LISTEN_ADMIN_ACCESS, access ) ~= nil then -- Gues they're the admin
		return true
	else
		return false
	end
end

function addSayCommand( command, call_function )
end

-- addUser - Adds a user to our permanent access list
function addUser( steamID, access ) 
	gUsers[ steamID ] = access
	return
end

-- ULX_CONVAR - Adds a convar with only the specified access allowed ( if left nil it will allow everyone )
function ULX_CONVAR( cvar_name, default, cmd_access, cmd_help )
	_G[ cvar_name ] = default
	
	_G[ "cc_" .. cvar_name ] = function ( userid, args ) -- This function will handle the cvar ( command ) callback
		if access ~= nil then
			if hasAccess( userid, cmd_access ) == false then
				_PrintMessage( userid, HUD_PRINTCONSOLE, "You lack sufficient access to use this cvar!\n" )
				return
			end
		end
		if args == "" then
			if cmd_help ~= nil then
				_PrintMessage( userid, HUD_PRINTCONSOLE, "\"" .. cvar_name .. "\" = \"" .. _G[ cvar_name ] .. "\"\n  " .. cmd_help .. "\n  CVAR generated by UMX\n")
			else
				_PrintMessage( userid, HUD_PRINTCONSOLE, "\"" .. cvar_name .. "\" = \"" .. _G[ cvar_name ] .. "\"\n  CVAR generated by UMX\n")
			end
		end
		_G[ cvar_name ] = args
	end
	
	local temp = loadstring( "return cc_" .. cvar_name ) -- We use this to convert a string to a function call
	CONCOMMAND( cvar_name, temp() )
	
	-- Now let's add to your help database!
	if cmd_help ~= nil then
		temp = cvar_name .. " " .. cmd_help .. "\n"
		table.insert( gCmdHelp, { access=cmd_access, help=temp } )
	else
		temp = cvar_name .. " - No help available\n"
	table.insert( gCmdHelp, { access=cmd_access, help=temp } )
	end	
end

-- ULX_CONCOMMAND - Adds a command with only the specified access allowed ( if left nil it will allow everyone )
function ULX_CONCOMMAND( command, fn_call, cmd_access, cmd_help, min_args, say_cmd )
	-- Let's do some quick error checking, so we won't have reoccuring problems later
	local error_flag = false
	if command == nil or command == "" or type( command ) ~= "string" then
		error_msg( "ULX_CONCOMMAND did not recieve a valid string for the command argument!" )
		error_flag = true
	end
	
	if fn_call == nil or type( fn_call ) ~= "function" then
		error_msg( "ULX_CONCOMMAND did not recieve a valid function for the fn_call argument!" )
	end
	
	if cmd_access ~= nil then
		if cmd_access == "" then
			cmd_access = nil
		elseif	type( cmd_access ) ~= "string" then
			error_msg( "ULX_CONCOMMAND did not recieve a valid string for the access argument! ( This is an optional arg )" )
			error_flag = true			
		end
	end
	
	if cmd_help ~= nil then
		if cmd_help == "" then
			cmd_help = nil
		elseif	type( cmd_help ) ~= "string" then
			error_msg( "ULX_CONCOMMAND did not recieve a valid string for the help argument! ( This is an optional arg )" )
			error_flag = true			
		end
	end
	
	if min_args ~= nil then
		if	type( min_args ) ~= "number" or min_args < 0 then
			error_msg( "ULX_CONCOMMAND did not recieve a valid number for the min_args argument! ( This is an optional arg )" )
			error_flag = true			
		end
	end
	
	if say_cmd ~= nil then
		if type( say_cmd ) ~= "string" or say_cmd == "" then
			error_msg( "ULX_CONCOMMAND did not recieve a valid string for the say_cmd argument! ( This is an optional arg )" )
			error_flag = true
		end
	end				
	
	if error_flag then -- Help them out a bit by showing the function call
		error_msg( "The function call to ULX_CONCOMMAND was ULX_CONCOMMAND( " .. tostring( command ) .. ", " .. tostring( fn_call ) .. ", " .. tostring( cmd_access) .. ", " .. tostring( cmd_help ) .. ", " .. tostring( min_args ) .. ", " .. tostring( say_cmd ) .. " )" )
	end

	_G[ "ccULX_" .. command ] = function ( userid, args ) -- This function will handle the command callback, and call the user specified call back after an access check
		if cmd_access ~= nil then
			if hasAccess( userid, cmd_access ) == false then
				_PrintMessage( userid, HUD_PRINTCONSOLE, "You lack sufficient access to use this command!\n" )
				return
			end
		end
		
		local argv = {}
		local argc
		argv, argc = splitArgs( args )
	
		if min_args ~= nil then
			if argc < min_args then
				_PrintMessage( userid, HUD_PRINTCONSOLE, "Insufficient parameters!\n" )
				return
			end
		end
		
		fn_call( userid, args, argv, argc )
	end
	
	local temp = loadstring( "return ccULX_" .. command ) -- We use this to convert a string to a function call
	CONCOMMAND( command, temp() )
	
	-- Now let's add to our help database!	
	if cmd_help ~= nil then
		if say_cmd ~= nil then
			temp = cmd_help .. " ( say: " .. say_cmd .. " )\n"
		else
			temp = cmd_help .. "\n"
		end
		table.insert( gCmdHelp, { cmd=command, access=cmd_access, help=temp } )
	else
		temp = " - No help available\n"
		table.insert( gCmdHelp, { cmd=command, access=cmd_access, help=temp } )
	end
	
	-- If they want it to be a say command, add it
	if say_cmd ~= nil then
		gSayCmds[ say_cmd ] = { fn=fn_call, access=cmd_access, minArgs=min_args }
	end
end
