-- cc_ulxSlay - responds to ulx_slay <user>, slays the specified user
function cc_ulxSlay( userid, args, argv, argc )
	local target = getUser( userid, argv[ 1 ] )
	if target == nil then
		return
	end
	
	_PlayerKill( target )
end

ULX_CONCOMMAND( "ulx_slay", cc_ulxSlay, ACCESS_SLAY, "<user> - slays the specified user", 1, "slay" )

-- cc_ulxSSlay - responds to ulx_sslay <user> [<respawn time> [<bool disolve]], slays the specified user
function cc_ulxSSlay( userid, args, argv, argc )	
	local target = getUser( userid, argv[ 1 ] )
	if target == nil then
		return
	end
	
	local respawn_time = 3
	local dissolve = true
	
	if argv[ 2 ] ~= nil then -- if they specified respawn time
		local num = tonumber( argv[ 2 ] )
		if num ~= nil then
			respawn_time = num
		end
	end
	
	if argv[ 3 ] ~= nil then -- if they specified dissolve
		local num = tonumber( argv[ 3 ] )
		if num ~= nil then
			if num == 0 then
				dissolve = false
			else
				dissolve = true
			end
		else  --It must be a boolean, so just assign it as such
			if argv[ 3 ] == "true" then
				dissolve = true
			else
				dissolve = false
			end
		end
	end
	
	_PlayerSilentKill( target, respawn_time, dissolve )
end

ULX_CONCOMMAND( "ulx_sslay", cc_ulxSSlay, ACCESS_SLAY, "<user> [<respawn time> [<bool disolve]] - silently slays the specified user", 1, "sslay" )

-- cc_ulxSlay - responds to ulx_slap <user> [<damage>], slaps the specified user with optional damage
function cc_ulxSlap( userid, args, argv, argc )
	local target = getUser( userid, argv[ 1 ] )
	if target == nil then
		return
	end	
	
	local vec = { x=math.random( 20 )-10, y=math.random( 20 )-10, z=math.random( 20 )-7 }
	vec = vecNormalize( vec )  -- This should make the slaps more equal in force, no matter what the direction
	vec = vecMul( vec, vector3( 1000, 1000, 1000 ) ) -- Now make the slap stronger
	
	_EntSetVelocity( target, vec )
	
	if argv[ 2 ] ~= nil then
		local dmg = tonumber( argv[ 2 ] )
		if dmg == nil then
			return; -- Unrecognized paramater, ignore it.
		end
		
		local curHp = _PlayerInfo( target, "health" )
		local newHp = curHp - dmg
		
		if newHp <= 0 then
			_PlayerKill( target )
		end
		
		_PlayerSetHealth( target, newHp )
	end
end

ULX_CONCOMMAND( "ulx_slap", cc_ulxSlap, ACCESS_SLAY, "<user> [<damage>] - slaps the specified user with optional damage", 1, "slap" )

-- cc_ulxIgnite - responds to ulx_ignite <user>, ignites the specified user
function cc_ulxIgnite( userid, args, argv, argc )
	local target = getUser( userid, argv[ 1 ] )
	if target == nil then
		return
	end
	
	_PlayerSetHealth( target, 139 ) -- This is so the person doesn't keep dying in the next spawn
	_EntFire( target, "ignite", 1, 0 ) -- ent_fire an entity. Syntax <entid> <action> <value> <delay> 
end

ULX_CONCOMMAND( "ulx_ignite", cc_ulxIgnite, ACCESS_SLAY, "<user> - ignites the specified user ( death by fire )", 1, "ignite" )

-- cc_ulxFreeze - responds to ulx_freeze <user>
function cc_ulxFreeze( userid, args, argv, argc )
	local target = getUser( userid, argv[ 1 ] )
	if target == nil then
		return
	end
	
	_PlayerFreeze( target, true )
end

ULX_CONCOMMAND( "ulx_freeze", cc_ulxFreeze, ACCESS_SLAY, "<user> - freezes the specified player ( unable to move or aim )", 1, "freeze" )

-- cc_ulxUnfreeze - responds to ulx_unfreeze <user>
function cc_ulxUnfreeze( userid, args, argv, argc )
	local target = getUser( userid, argv[ 1 ] )
	if target == nil then
		return
	end
	
	_PlayerFreeze( target, false )
end

ULX_CONCOMMAND( "ulx_unfreeze", cc_ulxUnfreeze, ACCESS_SLAY, "<user> - unfreezes the specified player", 1, "unfreeze" )
