-- trim - Removes leading or trailing whitespace
function trim ( s )
	return string.gsub( s, "^%s*(.-)%s*$", "%1" )
end

-- stripQuotes - Used to strip quotes from strings
function stripQuotes( s )
	return string.gsub( s, "^[\"]*(.-)[\"]*$", "%1" )
end


-- splitArgs - Used for splitting console arguments, will obey quotation marks
function splitArgs( args )
	local argv = {}
	local argc = 0
	local quoteFlag = false
	local strStore = ""
	
	for a in string.gfind( args, "[%a%p%d]+") do
		if a ~= nil then
			if quoteFlag == false then
				if string.sub( a, 1, 1 ) == "\"" then -- If we're beginning a quote
					quoteFlag = true
					strStore = a -- Since this is the beginning, assign the store the beginning
				else
					table.insert( argv, a )
					argc = argc + 1
				end
			else -- If quoteFlag is true
				if string.sub( a, -1, -1 ) == "\"" then -- If we're ending our quote
					quoteFlag = false
					strStore = strStore .. " " .. a
					strStore = stripQuotes( strStore )
					table.insert( argv, strStore )
					argc = argc + 1
				else
					strStore = strStore .. " " .. a -- Add to our store
				end
			end
		end
	end
	
	return argv, argc
end

function debug( text )
	if DEBUG_MODE then
		_Msg( "[ULX] Debug: " .. text .. "\n" )
	end
end

function error_msg( text )
	_Msg( "[ULX] ERROR: " .. text .. "\n" )
end
